"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var modal_utils_1 = require("../../utils/modal.utils");
var ModalComponent = (function () {
    /**
     *
     */
    function ModalComponent(componentFactoryResolver) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.isVisible = false;
        this.closed = new core_1.EventEmitter();
        this.config = {
            title: "Modal Head",
            btnOk: "Ok",
            btnCancel: "Abbrechen"
        };
        this.isVisible = true;
    }
    /**
     * Initializes the Modal if it's in Component Mode
     */
    ModalComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (this.config.component != null) {
            this.buildComponentInstance();
        }
        if (this.config.closeOn != null) {
            this.config.closeOn.subscribe(function (eventDataResult) {
                _this.onClick(eventDataResult);
            });
        }
        if (this.config.onOpen != null) {
            this.config.onOpen(this.getModalCtrl());
        }
    };
    /**
     * Builds an Instance of the given Component (see global Component Config)
     * Process is delayed because of some problems while loading to early
     */
    ModalComponent.prototype.buildComponentInstance = function () {
        var that = this;
        setTimeout(function () {
            var componentFactory = that.componentFactoryResolver.resolveComponentFactory(that.config.component);
            that.componentRef = that.target.createComponent(componentFactory);
            /** @var this.componentRef._component Modalable */
            that.componentRef._component.onModalOpen(that.config.componentParams || {}, that.getModalCtrl());
        }, 50);
    };
    /**
     * Returns an object literal to control the modal from outside (the component context)
     */
    ModalComponent.prototype.getModalCtrl = function () {
        var _this = this;
        return {
            close: function (result) {
                _this.onClick(result);
            },
            config: this.config,
            component: (this.componentRef !== undefined) ? this.componentRef._component : null
        };
    };
    /**
     * Returns the Header TemplateRef if it was specified in Modal config
     */
    ModalComponent.prototype.getHeaderTemplate = function () {
        if (this.config.template && this.config.template.header) {
            return this.config.template.header;
        }
    };
    /**
     * Returns the Body TemplateRef if it was specified in Modal config
     */
    ModalComponent.prototype.getBodyTemplate = function () {
        if (this.config.template && this.config.template.body) {
            return this.config.template.body;
        }
    };
    /**
     * Returns the Footer TemplateRef if it was specified in Modal config
     */
    ModalComponent.prototype.getFooterTemplate = function () {
        if (this.config.template && this.config.template.footer) {
            return this.config.template.footer;
        }
    };
    /**
     * Modal get's closed...
     * Return the ClosingResult (OK=true; Cancel=false;)
     * If the Modal was holding a Component, also return the Component.onModalClose result
     *
     * @param result
     */
    ModalComponent.prototype.onClick = function (result) {
        var _this = this;
        if (this.config.onClose != null) {
            this.config.onClose(result, this.getModalCtrl(), function (result) { return _this.closeModal(result); });
            return;
        }
        this.closeModal(result);
    };
    /**
     *
     * @param result
     */
    ModalComponent.prototype.closeModal = function (result) {
        this.isVisible = false;
        if (this.config.isComponent) {
            var modalComponent = this.componentRef._component;
            result = {
                closingResult: result,
                componentResult: modalComponent.onModalClose(result)
            };
            this.emitResult(result);
        }
        else if (this.config.isPrompt) {
            if (result) {
                this.emitResult(this.promptValue);
                this.promptValue = "";
            }
            else {
                this.emitResult(result);
            }
        }
        else {
            this.emitResult(result);
        }
        this.closed.emit(true);
    };
    /**
     *
     */
    ModalComponent.prototype.emitResult = function (result) {
        modal_utils_1.ModalUtils.modalResult.next({ result: result, instanceId: this.config.instanceId });
    };
    /**
     * Returns inline styles formatted as object (to bind to ngStyle)
     */
    ModalComponent.prototype.getStyles = function () {
        return {
            "width": this.config.width
        };
    };
    return ModalComponent;
}());
ModalComponent.decorators = [
    { type: core_1.Component, args: [{
                selector: 'modal',
                template: "\n      <div *ngIf=\"isVisible\" class=\"modal fade in\" id=\"simpleModal\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"simpleModalLabel\" aria-hidden=\"false\" style=\"display: block; padding-right: 15px;\">\n\n          <div class=\"modal-backdrop fade in\" style=\"height: 100vh;\"></div>\n          <div class=\"modal-dialog\" [ngStyle]=\"getStyles()\" style=\"z-index:1041\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-header\">\n                      <h4 *ngIf=\"!config.template?.header\" class=\"modal-title\">{{config.title}}</h4>\n                      <ng-template *ngIf=\"config.template?.header\" [ngTemplateOutlet]=\"getHeaderTemplate()\"></ng-template>\n                  </div>\n\n                  <div class=\"modal-body\">\n                      <div class=\"moda-body-content\" >\n                          <ng-container *ngIf=\"config.isComponent\">\n                              <div #modelContentComponent></div>\n                          </ng-container>\n\n                          <ng-container *ngIf=\"config.isAlert\">\n                              <p *ngIf=\"!config.template?.body\">{{config.body}}</p>\n                              <ng-template *ngIf=\"config.template?.body\" [ngTemplateOutlet]=\"getBodyTemplate()\"></ng-template>\n                          </ng-container>\n\n                          <ng-container *ngIf=\"config.isConfirm\">\n                              <p>{{config.body}}</p>\n                              <ng-template *ngIf=\"config.template?.body\" [ngTemplateOutlet]=\"getBodyTemplate()\"></ng-template>\n                          </ng-container>\n\n                          <ng-container *ngIf=\"config.isPrompt\">\n                              <ng-container *ngIf=\"!config.template?.body\">\n                                  <p>{{config.body}}</p>\n                                  <div class=\"form-group\">\n                                      <label class=\"control-label\">{{config.label}}</label>\n                                      <input type=\"text\" name=\"promptValue\" class=\"form-control\" [(ngModel)]=\"promptValue\" autofocus>\n                                  </div>\n                              </ng-container>\n                              <ng-template *ngIf=\"config.template?.body\" [ngTemplateOutlet]=\"getBodyTemplate()\"></ng-template>\n                          </ng-container>\n                      </div>\n                  </div>\n                  <div class=\"modal-footer\">\n                      <ng-container *ngIf=\"config.template?.footer\" [ngTemplateOutlet]=\"getFooterTemplate()\" [ngTemplateOutletContext]=\"{modalCtrl:getModalCtrl()}\"></ng-container>\n                      <div *ngIf=\"!config.template?.footer\">\n                          <button type=\"button\" class=\"btn btn-default\" (click)=\"onClick(false)\" *ngIf=\"!config.isAlert && config.btnCancelVisible\">{{config.btnCancel}}</button>\n                          <button type=\"button\" class=\"btn btn-primary\" (click)=\"onClick(true)\">{{config.btnOk}}</button>\n                      </div>\n                  </div>\n              </div>\n          </div>\n      </div>\n    ",
            },] },
];
/** @nocollapse */
ModalComponent.ctorParameters = function () { return [
    { type: core_1.ComponentFactoryResolver, },
]; };
ModalComponent.propDecorators = {
    'target': [{ type: core_1.ViewChild, args: ['modelContentComponent', { read: core_1.ViewContainerRef },] },],
    'closed': [{ type: core_1.Output },],
    'config': [{ type: core_1.Input },],
};
exports.ModalComponent = ModalComponent;
//# sourceMappingURL=modal.component.js.map