"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var BehaviorSubject_1 = require("rxjs/BehaviorSubject");
var core_1 = require("@angular/core");
require("rxjs/add/operator/toPromise");
var ModalUtils = (function () {
    function ModalUtils() {
    }
    /**
     * Opening a Modal for displaying a dynamically rendered Component
     * The Component must be passed by config key "component" and has to implement the Modalable Interface
     * The Result is an object containing the closingResult (Ok=true; Cancel=false;) and the componentResult which contains
     * ... the return value of the Components.onModalClose() Method
     * @returns {ModalUtils}
     */
    ModalUtils.component = function (config, component) {
        var instanceId = this.getInstanceId(config);
        var modalConfiguration = Object.assign(ModalUtils.defaultConfig, ModalUtils.resetConf, { isComponent: true, component: component }, config, instanceId);
        ModalUtils.configuration.next(modalConfiguration);
        return new Promise(function (resolve, reject) {
            ModalUtils.modalResult.subscribe(function (result) {
                if (result.instanceId == instanceId.instanceId) {
                    resolve(result.result);
                }
            });
        });
    };
    /**
     * Opening a Modal for displaying an Alert
     * @returns {ModalUtils}
     */
    ModalUtils.alert = function (config) {
        var instanceId = this.getInstanceId(config);
        var modalConfiguration = Object.assign(ModalUtils.defaultConfig, ModalUtils.resetConf, { isAlert: true }, config, instanceId);
        ModalUtils.configuration.next(modalConfiguration);
        return new Promise(function (resolve, reject) {
            ModalUtils.modalResult.subscribe(function (result) {
                if (result.instanceId == instanceId.instanceId) {
                    resolve(result.result);
                }
            });
        });
    };
    /**
     * Opening a Modal for displaying an Prompt
     * The prompted result ist available inside the resolving Promise Parameter "result" as string
     * ... if Modal is closed with cancel, result is boolean false
     * @returns {ModalUtils}
     */
    ModalUtils.prompt = function (config) {
        var instanceId = this.getInstanceId(config);
        var modalConfiguration = Object.assign(ModalUtils.defaultConfig, ModalUtils.resetConf, { isPrompt: true }, config, instanceId);
        ModalUtils.configuration.next(modalConfiguration);
        return new Promise(function (resolve, reject) {
            ModalUtils.modalResult.subscribe(function (result) {
                if (result.instanceId == instanceId.instanceId) {
                    resolve(result.result);
                }
            });
        });
    };
    /**
     * Opening a Modal for displaying an Confirmation
     * The closing result ist available inside the resolving Promise Parameter "result" as boolean
     * @returns {ModalUtils}
     */
    ModalUtils.confirm = function (config) {
        var instanceId = this.getInstanceId(config);
        var modalConfiguration = Object.assign(ModalUtils.defaultConfig, ModalUtils.resetConf, { isConfirm: true }, config, instanceId);
        ModalUtils.configuration.next(modalConfiguration);
        return new Promise(function (resolve, reject) {
            ModalUtils.modalResult.subscribe(function (result) {
                if (result.instanceId == instanceId.instanceId) {
                    resolve(result.result);
                }
            });
        });
    };
    /**
     *
     * @param config
     */
    ModalUtils.getInstanceId = function (config) {
        var instanceId = Math.floor((1 + Math.random()) * 0x10000).toString(16);
        if (config.hasOwnProperty('instanceId')) {
            config.instanceId.value = instanceId;
        }
        return {
            instanceId: instanceId
        };
    };
    return ModalUtils;
}());
ModalUtils.defaultConfig = {
    title: "Modal Head",
    body: "",
    width: "600px"
};
//public static configuration = new BehaviorSubject(ModalUtils.defaultConfig);
ModalUtils.configuration = new BehaviorSubject_1.BehaviorSubject(null);
ModalUtils.modalResult = new core_1.EventEmitter();
ModalUtils.resetConf = {
    isAlert: false,
    isPrompt: false,
    isConfirm: false,
    isComponent: false,
    component: null,
    width: "600px",
    template: {},
    onClose: null,
    btnOk: "OK",
    btnCancel: "Abbrechen",
    btnOkVisible: true,
    btnCancelVisible: true
};
exports.ModalUtils = ModalUtils;
//# sourceMappingURL=modal.utils.js.map